==> python-squall-0.1.1.tar.gz: python-squall-0.1.1/tests/test_invalid_path_param.py <==
from typing import Dict, List, Tuple

import pytest
from squall import Squall


def test_invalid_sequence():
    with pytest.raises(AssertionError):
        app = Squall()

        class Item:
            title: str

        @app.get("/items/{id}")
        def read_items(id: List[Item]):
            pass  # pragma: no cover


def test_invalid_tuple():
    with pytest.raises(AssertionError):
        app = Squall()

        class Item:
            title: str

        @app.get("/items/{id}")
        def read_items(id: Tuple[Item, Item]):
            pass  # pragma: no cover


def test_invalid_dict():
    with pytest.raises(AssertionError):
        app = Squall()

        class Item:
            title: str

        @app.get("/items/{id}")
        def read_items(id: Dict[str, Item]):
            pass  # pragma: no cover


def test_invalid_simple_list():
    with pytest.raises(AssertionError):
        app = Squall()

        @app.get("/items/{id}")
        def read_items(id: list):
            pass  # pragma: no cover


def test_invalid_simple_tuple():
    with pytest.raises(AssertionError):
        app = Squall()

        @app.get("/items/{id}")
        def read_items(id: tuple):
            pass  # pragma: no cover


def test_invalid_simple_set():
    with pytest.raises(AssertionError):
        app = Squall()

        @app.get("/items/{id}")
        def read_items(id: set):
            pass  # pragma: no cover


def test_invalid_simple_dict():
    with pytest.raises(AssertionError):
        app = Squall()

        @app.get("/items/{id}")
        def read_items(id: dict):
            pass  # pragma: no cover

==> python-squall-0.3.0.tar.gz: python-squall-0.3.0/tests/test_invalid_path_param.py <==
from typing import Dict, List, Tuple

import pytest
from squall import Squall


def test_invalid_sequence():
    with pytest.raises(ValueError):
        app = Squall()

        class Item:
            title: str

        @app.get("/items/{id}")
        def read_items(id: List[Item]):
            pass  # pragma: no cover


def test_invalid_tuple():
    with pytest.raises(ValueError):
        app = Squall()

        class Item:
            title: str

        @app.get("/items/{id}")
        def read_items(id: Tuple[Item, Item]):
            pass  # pragma: no cover


def test_invalid_dict():
    with pytest.raises(ValueError):
        app = Squall()

        class Item:
            title: str

        @app.get("/items/{id}")
        def read_items(id: Dict[str, Item]):
            pass  # pragma: no cover


def test_invalid_simple_list():
    with pytest.raises(ValueError):
        app = Squall()

        @app.get("/items/{id}")
        def read_items(id: list):
            pass  # pragma: no cover


def test_invalid_simple_tuple():
    with pytest.raises(ValueError):
        app = Squall()

        @app.get("/items/{id}")
        def read_items(id: tuple):
            pass  # pragma: no cover


def test_invalid_simple_set():
    with pytest.raises(ValueError):
        app = Squall()

        @app.get("/items/{id}")
        def read_items(id: set):
            pass  # pragma: no cover


def test_invalid_simple_dict():
    with pytest.raises(ValueError):
        app = Squall()

        @app.get("/items/{id}")
        def read_items(id: dict):
            pass  # pragma: no cover
